#ifndef __KIPINA_INTL_H__
#define __KIPINA_INTL_H__


#ifdef HAVE_CONFIG_H
#include "config.h"
#endif /* HAVE_CONFIG_H */

#ifndef LIBGNOME_H
#ifdef ENABLE_NLS
#define _(String) gettext(String)
#include <libintl.h>
#ifdef gettext_noop
#define N_(String) gettext_noop(String)
#else
#define N_(String) (String)
#endif
#else /* NLS is disabled */
#define _(String) (String)
#define N_(String) (String)
#define textdomain(String) (String)
#define gettext(String) (String)
#define dgettext(Domain,String) (String)
#define dcgettext(Domain,String,Type) (String)
#define bindtextdomain(Domain,Directory) (Domain) 
#define bind_textdomain_codeset(Domain,Codeset) (Codeset) 
#endif /* ENABLE_NLS */
#endif /* LIBGNOME_H */

#endif /* __KIPINA_INTL_H__ */
